package be.iminds.ilabt.jfed.lowlevel.testbed_info;

import be.iminds.ilabt.jfed.fedmon.webapi.service.json.Server;
import be.iminds.ilabt.jfed.util.library.JFedTrustStore;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.Collection;
import java.util.Collections;
import java.util.stream.Collectors;

/**
 * ServerTrustInfo: Wraps Server so it is a JFedTrustStore.TrustInfo
 */
public class ServerTrustInfo implements JFedTrustStore.TrustInfo {
    private final Server server;

    public ServerTrustInfo(Server server) {
        this.server = server;
    }


    @Nullable
    @Override
    public String getCertificateChain() {
        return server.getCertificateChain();
    }

    @Nullable
    @Override
    public String getAllowedCertificateAlias() {
        return server.getAllowedCertificateAlias();
    }

    public static JFedTrustStore.TrustInfo emptyTrustInfo = new JFedTrustStore.TrustInfo() {
        @Nullable
        @Override
        public String getCertificateChain() {
            return null;
        }

        @Nullable
        @Override
        public String getAllowedCertificateAlias() {
            return null;
        }
    };

    @Nonnull
    public static JFedTrustStore.TrustInfo convert(@Nullable Server server) {
        if (server == null) return emptyTrustInfo;
        return new ServerTrustInfo(server);
    }
    @Nonnull
    public static Collection<JFedTrustStore.TrustInfo> convert(@Nullable Collection<Server> servers) {
        if (servers == null) return Collections.emptyList();
        return servers.stream().map(ServerTrustInfo::new).collect(Collectors.toList());
    }
    @Nonnull
    public static Collection<JFedTrustStore.TrustInfo> convert(@Nullable TestbedInfoSource testbedInfoSource) {
        if (testbedInfoSource == null) return Collections.emptyList();
        return convert(testbedInfoSource.getServers());
    }
}
